from setuptools import setup, find_packages

setup(
    name="AkramMajli",
    version="0.1.0",
    packages=find_packages(),
    install_requires=[],
    url="https://example.com",  # رابط صالح لتجنب خطأ URL
    author="Akram Majli",
    author_email="akalm1900@gmail.com",
    description="A Python library with examples, functions, and plots.",
    long_description="Long description here",
    long_description_content_type="text/markdown",
    license="MIT",
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
)
